@@ -1,4 +1,4 @@
 from .steps import *
 from .base import Server, ClientHandler
-from .constants import HttpMethods, default_ssl_cert
+from .constants import (HttpMethods, default_ssl_cert)
 from .socket_utils import *
